package Alterator::Backend3;

use 5.008008;
use strict;
use warnings;


our $VERSION = '0.01';


# Preloaded methods go here.

sub new {
    my $class = shift;
    my $self = {};
    $self->{handler} = shift;
    bless( $self, $class);
    return $self;
}

sub message_loop{
    my $self = shift;
    my $limit = shift || 65536 ;
    my $i = 0;
    my $message = {};
    my $reading = undef;
    while( my $line = <STDIN> ){
	if( $line eq "_message:begin\n" ) {
	    $message = {};
	    $reading = 1;
	}
	elsif( $reading && $line eq "_message:end\n" ) {
	    undef $reading;
	    $self->{handler}->($message);	    
	    $i++;
	    if( $i >= $limit ){ last; }
	}
	else {
	    my ($name, $value ) = split /:/ ,$line,2; #/;
	    chomp($value);

	    $value =~ s/([^\\])\\n/$1\n/g;
	    $value =~ s/\\\\/\\/g;

	    $message->{$name} = $value;
	}
    }
    1;
}

1;
__END__
# Below is stub documentation for your module. You'd better edit it!

=head1 NAME

Alterator::Backend3 - Perl extension for writing backends for Alterator

=head1 SYNOPSIS

  use Alterator::Backend3;

  sub on_message {
      $message = shift;
      print $message->{action}'
  }  

  $back = Alterator::Backend3->new( \&on_message );

  $back->message_loop;

=head1 DESCRIPTION

This module can be used to write backends for ALTLinux Alterator system. 

=head2 EXPORT

None by default.



=head1 SEE ALSO

http://wiki.sisyphus.ru/Alterator/backend3

=head1 AUTHOR

Anton V. Boyarshinov, <lt>boyarah@altlinux.org<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2007 by Anton V. Boyarshinov

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.8.8 or,
at your option, any later version of Perl 5 you may have available.


=cut
